@@ -415,10 +415,12 @@ class Node(object):
             if results.status_code:
                 self.socketIO.emit(
                     'container_failed',
-                    self.server_io.id,
-                    results.status_code,
-                    results.result_id,
-                    self.server_io.collaboration_id,
+                    data={
+                        'node_id': self.server_io.whoami.id_,
+                        'status_code': results.status_code,
+                        'result_id': results.result_id,
+                        'collaboration_id': self.server_io.collaboration_id
+                    },
                     namespace='/tasks'
                 )
 
@@ -533,7 +535,6 @@ class Node(object):
             namespaces=['/tasks']
         )
 
-        # Connect to the /tasks namespace
         self.socketIO.register_namespace(NodeTaskNamespace('/tasks'))
         NodeTaskNamespace.node_worker_ref = self
 
